update_is_needed

Function update_is_needed 

pub fn update_is_needed(
    channel: ReleaseChannel,
    current_version: &str,
    latest_tag: &str,
) -> Result<bool>
Determines whether an update is needed for the given channel.

For Stable an update is needed when the latest release is strictly newer. For Beta the logic also allows switching from a stable release to a beta on the same release line.